@@ -8,7 +8,7 @@
 
 G_BEGIN_DECLS
 
-/* Enumerations from "./e-book-contacts-types.h" */
+/* Enumerations from "/usr/obj/ports/evolution-data-server-3.24.6/evolution-data-server-3.24.6/src/addressbook/libebook-contacts/e-book-contacts-types.h" */
 
 #define E_TYPE_BOOK_CLIENT_VIEW_FLAGS	(e_book_client_view_flags_get_type())
 GType e_book_client_view_flags_get_type	(void) G_GNUC_CONST;
@@ -19,15 +19,24 @@ GType e_book_client_error_get_type	(void) G_GNUC_CONST;
 #define E_TYPE_DATA_BOOK_STATUS	(e_data_book_status_get_type())
 GType e_data_book_status_get_type	(void) G_GNUC_CONST;
 
+#define E_TYPE_BOOK_INDEX_TYPE	(e_book_index_type_get_type())
+GType e_book_index_type_get_type	(void) G_GNUC_CONST;
+
+#define E_TYPE_BOOK_CURSOR_SORT_TYPE	(e_book_cursor_sort_type_get_type())
+GType e_book_cursor_sort_type_get_type	(void) G_GNUC_CONST;
+
+#define E_TYPE_BOOK_CURSOR_ORIGIN	(e_book_cursor_origin_get_type())
+GType e_book_cursor_origin_get_type	(void) G_GNUC_CONST;
+
+#define E_TYPE_BOOK_CURSOR_STEP_FLAGS	(e_book_cursor_step_flags_get_type())
+GType e_book_cursor_step_flags_get_type	(void) G_GNUC_CONST;
+
 #define E_TYPE_BOOK_VIEW_STATUS	(e_book_view_status_get_type())
 GType e_book_view_status_get_type	(void) G_GNUC_CONST;
 
 #define E_TYPE_BOOK_CHANGE_TYPE	(e_book_change_type_get_type())
 GType e_book_change_type_get_type	(void) G_GNUC_CONST;
 
-#define E_TYPE_BOOK_INDEX_TYPE	(e_book_index_type_get_type())
-GType e_book_index_type_get_type	(void) G_GNUC_CONST;
-
 G_END_DECLS
 
 #endif /* E_BOOK_CONTACTS_ENUMTYPES_H */
